[SCM] live-config branch, debian, updated. debian/3.0.7-1

Daniel Baumann daniel at debian.org
Thu Sep 27 10:57:49 UTC 2012


The following commit has been merged in the debian branch:
commit 41c9cc88537f3f48fc45e36f7a18a636c8049f80
Author: Daniel Baumann <daniel at debian.org>
Date:   Thu Sep 27 11:44:22 2012 +0200

    Moving remaining stuff from /live to /lib/live to avoid further namespace pollution.

diff --git a/manpages/de/live-config.de.7 b/manpages/de/live-config.de.7
index 8d24978..1465e69 100644
--- a/manpages/de/live-config.de.7
+++ b/manpages/de/live-config.de.7
@@ -11,7 +11,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-CONFIG 7 26.09.2012 3.0.6\-1 "Debian Live Projekt"
+.TH LIVE\-CONFIG 7 27.09.2012 3.0.6\-1 "Debian Live Projekt"
 
 .SH NAME
 \fBlive\-config\fP \- System Konfiguration Skripte
@@ -64,7 +64,7 @@ Datenbank anzuwenden. Die URLs müssen durch wget (http, ftp oder file://)
 aufösbar sein.
 .br
 Falls die Datei sich auf dem Live Medium befindet, kann sie mittels
-file:///live/image/\fIFILE\fP benutzt werden, falls sie sich im Root
+file:///lib/live/image/\fIFILE\fP benutzt werden, falls sie sich im Root
 Dateisystem des Live Systems selbst befindet, mittels file:///\fIFILE\fP.
 .br
 Alle Preseed Dateien in /lib/live/preseed/ im Root Dateisystem des Live
@@ -137,7 +137,7 @@ Anwendungsfälle sind in /usr/share/doc/live\-config/examples/hooks/ und unter
 <\fIhttp://live.debian.net/other/hooks\fP> verfügbar.
 .br
 Falls die Datei sich auf dem Live Medium befindet, kann sie mittels
-file:///live/image/\fIFILE\fP benutzt werden, falls sie sich im Root
+file:///lib/live/image/\fIFILE\fP benutzt werden, falls sie sich im Root
 Dateisystem des Live Systems selbst befindet, mittels file:///\fIFILE\fP.
 .br
 Alle Dateien in /lib/live/hooks/ im Root Dateisystem des Live Systems können
diff --git a/manpages/en/live-config.7 b/manpages/en/live-config.7
index f36126e..0d5b6f6 100644
--- a/manpages/en/live-config.7
+++ b/manpages/en/live-config.7
@@ -6,7 +6,7 @@
 .\" under certain conditions; see COPYING for details.
 .\"
 .\"
-.TH LIVE\-CONFIG 7 2012\-09\-26 3.0.6-1 "Debian Live Project"
+.TH LIVE\-CONFIG 7 2012\-09\-27 3.0.6-1 "Debian Live Project"
 
 .SH NAME
 \fBlive\-config\fR \- System Configuration Scripts
@@ -37,7 +37,7 @@ Some individual scripts can change their behaviour upon a boot parameter.
 .IP "\fBlive\-config.debconf\-preseed\fR=filesystem|medium|\fIURL1\fR|\fIURL2\fR| ... |\fIURLn\fR | \fBdebconf\-preseed\fR=medium|filesystem|\fIURL1\fR|\fIURL2\fR| ... |\fIURLn\fR" 4
 Allows to fetch and apply one or more debconf preseed files to be applied to the debconf database. Note that the URLs must be fetchable by wget (http, ftp or file://).
 .br
-If the file is placed on the live medium, it can be fetched with file:///live/image/\fIFILE\fR, or with file:///\fIFILE\fR if it is in the root filesystem of the live system itself.
+If the file is placed on the live medium, it can be fetched with file:///lib/live/image/\fIFILE\fR, or with file:///\fIFILE\fR if it is in the root filesystem of the live system itself.
 .br
 All preseed files in /lib/live/preseed/ in the root filesystem of the live system can be automatically be enabled with the keyword 'filesystem'.
 .br
@@ -77,7 +77,7 @@ Allows to set xorg resolution instead of autodetecting it, e.g. 1024x768.
 .IP "\fBlive\-config.hooks\fR=filesystem|medium|\fIURL1\fR|\fIURL2\fR| ... |\fIURLn\fR | \fBhooks\fR=medium|filesystem|\fIURL1\fR|\fIURL2\fR| ... |\fIURLn\fR" 4
 Allows to fetch and execute one or more arbitrary files. Note that the URLs must be fetchable by wget (http, ftp or file://), the files are executed in /tmp of the running live system, and that the files needs their dependencies, if any, already installed, e.g. if a python script should be executed the system needs python installed. Some hooks for some common use-cases are available at /usr/share/doc/live-config/examples/hooks/ and <\fIhttp://live.debian.net/other/hooks\fR>.
 .br
-If the file is placed on the live medium, it can be fetched with file:///live/image/\fIFILE\fR, or with file:///\fIFILE\fR if it is in the root filesystem of the live system itself.
+If the file is placed on the live medium, it can be fetched with file:///lib/live/image/\fIFILE\fR, or with file:///\fIFILE\fR if it is in the root filesystem of the live system itself.
 .br
 All hooks in /lib/live/hooks/ in the root filesystem of the live system can be automatically be enabled with the keyword 'filesystem'.
 .br
diff --git a/manpages/es/live-config.es.7 b/manpages/es/live-config.es.7
index 1bdeda1..fe938b5 100644
--- a/manpages/es/live-config.es.7
+++ b/manpages/es/live-config.es.7
@@ -11,7 +11,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-CONFIG 7 26.09.2012 3.0.6\-1 "Proyecto Debian Live"
+.TH LIVE\-CONFIG 7 27.09.2012 3.0.6\-1 "Proyecto Debian Live"
 
 .SH NOMBRE
 \fBlive\-config\fP \- Scripts de configuración del sistema
@@ -62,7 +62,7 @@ base de datos de debconf. Tener en cuenta que las URLs deben poder ser
 descargadas por wget (http, ftp o file://).
 .br
 Si el archivo está en el medio en vivo, se puede obtener con
-file:///live/image/\fIFILE\fP, o con file:///\fIFILE\fP si se encuentra en el
+file:///lib/live/image/\fIFILE\fP, o con file:///\fIFILE\fP si se encuentra en el
 directorio raíz del sistema en vivo.
 .br
 Todos los ficheros de preconfiguración en /lib/live/preseed/ en el sistema
@@ -135,7 +135,7 @@ común disponibles en /usr/share/doc/live\-config/examples/hooks/ y en
 <\fIhttp://live.debian.net/other/hooks\fP>.
 .br
 Si el archivo está en el medio en vivo, se puede obtener con
-file:///live/image/\fIFILE\fP, o con file:///\fIFILE\fP si se encuentra en el
+file:///lib/live/image/\fIFILE\fP, o con file:///\fIFILE\fP si se encuentra en el
 directorio raíz del sistema en vivo.
 .br
 Todos los scripts gancho de /lib/live/hooks/ del directorio raíz del sistema
diff --git a/manpages/fr/live-config.fr.7 b/manpages/fr/live-config.fr.7
index c4ce68a..aaddfa1 100644
--- a/manpages/fr/live-config.fr.7
+++ b/manpages/fr/live-config.fr.7
@@ -11,7 +11,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-CONFIG 7 26.09.2012 3.0.6\-1 "Projet Debian Live"
+.TH LIVE\-CONFIG 7 27.09.2012 3.0.6\-1 "Projet Debian Live"
 
 .SH NOM
 \fBlive\-config\fP \- Scripts de configuration du système
@@ -64,8 +64,8 @@ préconfiguration debconf à la base de données debconf. Notez que les URLs
 doivent pouvoir être utilisées par wget (http, ftp or file://).
 .br
 Si le fichier est placé dans le média live, il peut être utilisé avec
-file:///live/image/\fIFILE\fP, ou bien avec file:///\fIFILE\fP s'il est placé à la
-racine du système de fichiers du système live.
+file:///lib/live/image/\fIFILE\fP, ou bien avec file:///\fIFILE\fP s'il est placé
+à la racine du système de fichiers du système live.
 .br
 Tous les fichiers de préconfiguration dans /lib/live/preseed/ dans le
 système de fichiers racine du système live peuvent être automatiquement
@@ -141,8 +141,8 @@ proposés dans /usr/share/doc/live\-config/examples/hooks/ et sur
 <\fIhttp://live.debian.net/other/hooks\fP>.
 .br
 Si le fichier est placé dans le média live, il peut être utilisé avec
-file:///live/image/\fIFILE\fP, ou bien avec file:///\fIFILE\fP s'il est placé à la
-racine du système de fichiers du système live.
+file:///lib/live/image/\fIFILE\fP, ou bien avec file:///\fIFILE\fP s'il est placé
+à la racine du système de fichiers du système live.
 .br
 Tous les hooks, placés dans /lib/live/hooks/ à la racine du système de
 fichiers, peuvent être automatiquement activés avec le mot clé 'filesystem'.
diff --git a/manpages/it/live-config.it.7 b/manpages/it/live-config.it.7
index fb9844c..c6e1b8c 100644
--- a/manpages/it/live-config.it.7
+++ b/manpages/it/live-config.it.7
@@ -11,7 +11,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-CONFIG 7 26.09.2012 3.0.6\-1 "Progetto Debian Live"
+.TH LIVE\-CONFIG 7 27.09.2012 3.0.6\-1 "Progetto Debian Live"
 
 .SH NOME
 \fBlive\-config\fP \- Script di configurazione del sistema
@@ -63,7 +63,7 @@ preconfigurazione da applicare al database debconf. Si noti che gli URL
 devono essere scaricabili da wget (http, ftp o file://).
 .br
 Se il file è posizionato sul supporto live, questo  può essere prelevato con
-file:///live/image/\fIFILE\fP, o con file:///\fIFILE\fP se è nella radice del
+file:///lib/live/image/\fIFILE\fP, o con file:///\fIFILE\fP se è nella radice del
 filesystem del sistema live stesso.
 .br
 Tutti i file di preconfigurazione in /lib/live/preseed/ nella radice del
@@ -136,7 +136,7 @@ disponibili alcuni hook per i casi d'uso più comuni in
 <\fIhttp://live.debian.net/other/hooks\fP>.
 .br
 Se il file è posizionato sul supporto live, questo  può essere prelevato con
-file:///live/image/\fIFILE\fP, o con file:///\fIFILE\fP se è nella radice del
+file:///lib/live/image/\fIFILE\fP, o con file:///\fIFILE\fP se è nella radice del
 filesystem del sistema live stesso.
 .br
 Tutti gli hook nella directory /lib/live/hooks/ del sistema live possono
diff --git a/manpages/po/de/live-config.7.po b/manpages/po/de/live-config.7.po
index 5f82bd3..b654662 100644
--- a/manpages/po/de/live-config.7.po
+++ b/manpages/po/de/live-config.7.po
@@ -5,7 +5,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config 3.0.6-1\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: 2010-05-24 09:59+0300\n"
 "Last-Translator: Daniel Baumann <daniel at debian.org>\n"
 "Language-Team: none\n"
@@ -24,8 +24,8 @@ msgstr "LIVE-CONFIG"
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
-msgstr "26.09.2012"
+msgid "2012-09-27"
+msgstr "27.09.2012"
 
 #. type: TH
 #: en/live-config.7:9
@@ -211,13 +211,13 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
 "Falls die Datei sich auf dem Live Medium befindet, kann sie mittels file:///"
-"live/image/I<FILE> benutzt werden, falls sie sich im Root Dateisystem des "
-"Live Systems selbst befindet, mittels file:///I<FILE>."
+"lib/live/image/I<FILE> benutzt werden, falls sie sich im Root Dateisystem "
+"des Live Systems selbst befindet, mittels file:///I<FILE>."
 
 #. type: Plain text
 #: en/live-config.7:43
diff --git a/manpages/po/es/live-config.7.po b/manpages/po/es/live-config.7.po
index e6687c3..c47c163 100644
--- a/manpages/po/es/live-config.7.po
+++ b/manpages/po/es/live-config.7.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config 3.0.6-1\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: 2012-07-28 22:11+0100\n"
 "Last-Translator: Carlos Zuferri <chals at altorricon.com>\n"
 "Language-Team: none\n"
@@ -25,8 +25,8 @@ msgstr "LIVE-CONFIG"
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
-msgstr "26.09.2012"
+msgid "2012-09-27"
+msgstr "27.09.2012"
 
 #. type: TH
 #: en/live-config.7:9
@@ -210,13 +210,13 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
-"Si el archivo está en el medio en vivo, se puede obtener con file:///live/"
-"image/I<FILE>, o con file:///I<FILE> si se encuentra en el directorio raíz "
-"del sistema en vivo."
+"Si el archivo está en el medio en vivo, se puede obtener con file:///lib/"
+"live/image/I<FILE>, o con file:///I<FILE> si se encuentra en el directorio "
+"raíz del sistema en vivo."
 
 #. type: Plain text
 #: en/live-config.7:43
diff --git a/manpages/po/fr/live-config.7.po b/manpages/po/fr/live-config.7.po
index 010a0f4..bf2a454 100644
--- a/manpages/po/fr/live-config.7.po
+++ b/manpages/po/fr/live-config.7.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config 3.0.6-1\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: 2012-07-28 22:13+0100\n"
 "Last-Translator: Carlos Zuferri <chals at altorricon.com>\n"
 "Language-Team: none\n"
@@ -25,8 +25,8 @@ msgstr "LIVE-CONFIG"
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
-msgstr "26.09.2012"
+msgid "2012-09-27"
+msgstr "27.09.2012"
 
 #. type: TH
 #: en/live-config.7:9
@@ -212,13 +212,13 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
 "Si le fichier est placé dans le média live, il peut être utilisé avec "
-"file:///live/image/I<FILE>, ou bien avec file:///I<FILE> s'il est placé à la "
-"racine du système de fichiers du système live."
+"file:///lib/live/image/I<FILE>, ou bien avec file:///I<FILE> s'il est placé "
+"à la racine du système de fichiers du système live."
 
 #. type: Plain text
 #: en/live-config.7:43
diff --git a/manpages/po/it/live-config.7.po b/manpages/po/it/live-config.7.po
index 984b3e9..7d3f35c 100644
--- a/manpages/po/it/live-config.7.po
+++ b/manpages/po/it/live-config.7.po
@@ -5,7 +5,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config 3.0.6-1\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: 2012-08-03 17:13+0200\n"
 "Last-Translator: skizzhg <skizzhg at gmx.com>\n"
 "Language-Team: none\n"
@@ -23,8 +23,8 @@ msgstr "LIVE-CONFIG"
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
-msgstr "26.09.2012"
+msgid "2012-09-27"
+msgstr "27.09.2012"
 
 #. type: TH
 #: en/live-config.7:9
@@ -209,12 +209,12 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
 "Se il file è posizionato sul supporto live, questo  può essere prelevato con "
-"file:///live/image/I<FILE>, o con file:///I<FILE> se è nella radice del "
+"file:///lib/live/image/I<FILE>, o con file:///I<FILE> se è nella radice del "
 "filesystem del sistema live stesso."
 
 #. type: Plain text
diff --git a/manpages/po/pt_BR/live-config.7.po b/manpages/po/pt_BR/live-config.7.po
index 24a7b29..dc63159 100644
--- a/manpages/po/pt_BR/live-config.7.po
+++ b/manpages/po/pt_BR/live-config.7.po
@@ -6,7 +6,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config 3.0.6-1\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: 2012-07-28 11:38-0400\n"
 "Last-Translator: Tiago Bortoletto Vaz <tiago at debian.org>\n"
 "Language-Team: none\n"
@@ -25,8 +25,8 @@ msgstr "LIVE-CONFIG"
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
-msgstr "26-09-2012"
+msgid "2012-09-27"
+msgstr "27-09-2012"
 
 #. type: TH
 #: en/live-config.7:9
@@ -210,13 +210,13 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
 "Se o arquivo estiver na mídia live, ele pode ser obtido através de file:///"
-"live/image/I<FILE> ou file:///I<FILE> se estiver no sistema raiz do próprio "
-"sistema live."
+"lib/live/image/I<FILE> ou file:///I<FILE> se estiver no sistema raiz do "
+"próprio sistema live."
 
 #. type: Plain text
 #: en/live-config.7:43
diff --git a/manpages/pot/live-config.7.pot b/manpages/pot/live-config.7.pot
index 5f1feaf..d6f0ca6 100644
--- a/manpages/pot/live-config.7.pot
+++ b/manpages/pot/live-config.7.pot
@@ -7,7 +7,7 @@
 msgid ""
 msgstr ""
 "Project-Id-Version: live-config VERSION\n"
-"POT-Creation-Date: 2012-09-26 14:23+0300\n"
+"POT-Creation-Date: 2012-09-27 11:41+0300\n"
 "PO-Revision-Date: YEAR-MO-DA HO:MI+ZONE\n"
 "Last-Translator: FULL NAME <EMAIL at ADDRESS>\n"
 "Language-Team: LANGUAGE <LL at li.org>\n"
@@ -25,7 +25,7 @@ msgstr ""
 #. type: TH
 #: en/live-config.7:9
 #, no-wrap
-msgid "2012-09-26"
+msgid "2012-09-27"
 msgstr ""
 
 #. type: TH
@@ -182,7 +182,7 @@ msgstr ""
 #. type: Plain text
 #: en/live-config.7:41 en/live-config.7:81
 msgid ""
-"If the file is placed on the live medium, it can be fetched with file:///"
+"If the file is placed on the live medium, it can be fetched with file:///lib/"
 "live/image/I<FILE>, or with file:///I<FILE> if it is in the root filesystem "
 "of the live system itself."
 msgstr ""
diff --git a/manpages/pt_BR/live-config.pt_BR.7 b/manpages/pt_BR/live-config.pt_BR.7
index 5d22c70..f39e4e4 100644
--- a/manpages/pt_BR/live-config.pt_BR.7
+++ b/manpages/pt_BR/live-config.pt_BR.7
@@ -11,7 +11,7 @@
 .\" This file was generated with po4a. Translate the source file.
 .\"
 .\"*******************************************************************
-.TH LIVE\-CONFIG 7 26\-09\-2012 3.0.6\-1 "Projeto Debian Live"
+.TH LIVE\-CONFIG 7 27\-09\-2012 3.0.6\-1 "Projeto Debian Live"
 
 .SH NOME
 \fBlive\-config\fP \- Scripts para Configuração do Sistema
@@ -62,8 +62,8 @@ inseridos na base de dados debconf.Note que as URLs devem ser alcançáveis
 via wget (http,ftp ou file://).
 .br
 Se o arquivo estiver na mídia live, ele pode ser obtido através de
-file:///live/image/\fIFILE\fP ou file:///\fIFILE\fP se estiver no sistema raiz do
-próprio sistema live.
+file:///lib/live/image/\fIFILE\fP ou file:///\fIFILE\fP se estiver no sistema raiz
+do próprio sistema live.
 .br
 Todos os arquivos de preseeds em /lib/live/preseed/ no sistema de arquivos
 raiz do sistema live podem ser automaticamente ativados com a palavra\-chave
@@ -133,8 +133,8 @@ disponíveis em /usr/share/doc/live\-config/examples/hooks/ e
 <\fIhttp://live.debian.net/other/hooks\fP>.
 .br
 Se o arquivo estiver na mídia live, ele pode ser obtido através de
-file:///live/image/\fIFILE\fP ou file:///\fIFILE\fP se estiver no sistema raiz do
-próprio sistema live.
+file:///lib/live/image/\fIFILE\fP ou file:///\fIFILE\fP se estiver no sistema raiz
+do próprio sistema live.
 .br
 Todos os hooks no diretório /lib/live/hooks do sistema de arquivos raiz do
 sistema live podem ser automaticamente habilitados com a palavra\-chave
diff --git a/scripts/config.sh b/scripts/config.sh
index 4694829..ec1af64 100755
--- a/scripts/config.sh
+++ b/scripts/config.sh
@@ -171,7 +171,7 @@ Main ()
 
 	# Reading configuration file from filesystem and live-media
 	for _FILE in /etc/live/config.conf /etc/live/config/* \
-		     /live/image/live/config.conf /live/image/live/config/*
+		     /lib/live/image/live/config.conf /lib/live/image/live/config/*
 	do
 		if [ -e "${_FILE}" ]
 		then
diff --git a/scripts/config/0010-debconf b/scripts/config/0010-debconf
index 051be41..67aeaf0 100755
--- a/scripts/config/0010-debconf
+++ b/scripts/config/0010-debconf
@@ -50,9 +50,9 @@ Configure_debconf ()
 				;;
 
 			medium)
-				if ls /live/image/live/preseed/* 2>&1
+				if ls /lib/live/image/live/preseed/* 2>&1
 				then
-					_PRESEEDS="${_PRESEEDS} $(for _FILE in /live/image/live/preseed/*; do echo file://${_FILE}; done)"
+					_PRESEEDS="${_PRESEEDS} $(for _FILE in /lib/live/image/live/preseed/*; do echo file://${_FILE}; done)"
 				fi
 				;;
 
diff --git a/scripts/config/9990-hooks b/scripts/config/9990-hooks
index d0b6e18..fa55eb0 100755
--- a/scripts/config/9990-hooks
+++ b/scripts/config/9990-hooks
@@ -47,9 +47,9 @@ Process_hooks ()
 				;;
 
 			medium)
-				if ls /live/image/live/hooks/* 2>&1
+				if ls /lib/live/image/live/hooks/* 2>&1
 				then
-					_HOOKS="${_HOOKS} $(for _FILE in /live/image/live/hooks/*; do echo file://${_FILE}; done)"
+					_HOOKS="${_HOOKS} $(for _FILE in /lib/live/image/live/hooks/*; do echo file://${_FILE}; done)"
 				fi
 				;;
 

diff --git a/bin/boot-init.sh b/bin/boot-init.sh
index 72c20f6..daaafab 100755
--- a/bin/boot-init.sh
+++ b/bin/boot-init.sh
@@ -65,10 +65,10 @@ cache_path()
 
 get_boot_device()
 {
 	# search in /proc/mounts for the device that is mounted at /live/image
 	while read DEVICE MOUNT REST
 	do
-		if [ "${MOUNT}" = "/live/image" ]
+		if [ "${MOUNT}" = "/lib/live/image" ]
 		then
 			echo "${DEVICE}"
 			exit 0
@@ -117,7 +117,7 @@ Eject ()
 
 		if [ -x /usr/bin/eject ]
 		then
-			eject -p -m /live/image >/dev/null 2>&1
+			eject -p -m /lib/live/image >/dev/null 2>&1
 		fi
 
 		if [ "${NOPROMPT}" = "cd" ]
@@ -154,10 +154,10 @@ do
 	cache_path "${path}"
 done
 
-mount -o remount,ro /live/overlay > /dev/null 2>&1
+mount -o remount,ro /lib/live/overlay > /dev/null 2>&1
 
 # Remounting any persistence devices read-only
-for _MOUNT in $(awk '/\/live\/persistence/ { print $2 }' /proc/mounts)
+for _MOUNT in $(awk '/\/lib\/live\/persistence/ { print $2 }' /proc/mounts)
 do
 	mount -o remount,ro ${_MOUNT} > /dev/null 2>&1
 done
@@ -65,10 +65,10 @@ cache_path()
 get_boot_device()
 {
-	# search in /proc/mounts for the device that is mounted at /live/image
+	# search in /proc/mounts for the device that is mounted at /lib/live/image
 	while read DEVICE MOUNT REST
 	do
-- 
live-config



More information about the debian-live-changes mailing list